@@ -18,39 +18,45 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import warnings
+from typing import Optional, Sequence
+
 from ._relic import (
     # BN
     BN,
     BN_from_int,
-    rand_BN_mod,
     neutral_BN,
+    rand_BN_mod,
+    rand_BN_order,
     # G1
     G1,
     generator_G1,
     hash_to_G1,
-    mul_sim_G1,
     neutral_G1,
     order,
+    power_product_G1,
+    product_G1,
     rand_G1,
-    rand_BN_order,
     # G2
     G2,
     generator_G2,
     hash_to_G2,
-    mul_sim_G2,
     neutral_G2,
+    power_product_G2,
+    product_G2,
     rand_G2,
     # Gt
     GT,
     generator_GT,
     neutral_GT,
+    product_GT,
     rand_GT,
     # pairings
     pair,
     pair_product,
 )
 
-__version__ = "0.2.1"
+__version__ = "0.3"
 __author__ = "Sebastian Ramacher"
 __license__ = "MIT"
 __copyright__ = f"(C) 2021 {__author__}"
@@ -69,13 +75,11 @@ def _init() -> None:
     if not core_success:
         raise RuntimeError("Failed to initialize relic (core)!")
     if not pair_success:
-        raise RuntimeError("Failed to initilaize relic (pairing)!")
+        raise RuntimeError("Failed to initialize relic (pairing)!")
 
 
 class Relic:
     def __init__(self) -> None:
-        import warnings
-
         warnings.warn(
             "Using Relic is deprecated and is no longer needed.", DeprecationWarning
         )
@@ -87,4 +91,18 @@ class Relic:
         pass
 
 
+def mul_sim_G1(
+    values: Sequence[G1], scalars: Sequence[BN], base: Optional[G1] = None
+) -> G1:
+    warnings.warn("Use power_product_G1 instead.", DeprecationWarning)
+    return power_product_G1(values, scalars, base)
+
+
+def mul_sim_G2(
+    values: Sequence[G2], scalars: Sequence[BN], base: Optional[G2] = None
+) -> G2:
+    warnings.warn("Use power_product_G2 instead.", DeprecationWarning)
+    return power_product_G2(values, scalars, base)
+
+
 _init()
